Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3141)

Unified Diff: app/win/drop_target.h

Issue 3822007: Move BaseDropTarget and BaseDragSource from base to app/win. Remove the "Base... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: Created 10 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « app/win/drag_source.cc ('k') | app/win/drop_target.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: app/win/drop_target.h
===================================================================
--- app/win/drop_target.h (revision 62848)
+++ app/win/drop_target.h (working copy)
@@ -2,30 +2,34 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef BASE_BASE_DROP_TARGET_H_
-#define BASE_BASE_DROP_TARGET_H_
+#ifndef APP_WIN_DROP_TARGET_H_
+#define APP_WIN_DROP_TARGET_H_
#pragma once
#include <objidl.h>
#include "base/ref_counted.h"
+// Windows interface.
struct IDropTargetHelper;
+namespace app {
+namespace win {
+
// A DropTarget implementation that takes care of the nitty gritty
// of dnd. While this class is concrete, subclasses will most likely
// want to override various OnXXX methods.
//
// Because BaseDropTarget is ref counted you shouldn't delete it directly,
// rather wrap it in a scoped_refptr. Be sure and invoke RevokeDragDrop(m_hWnd)
// before the HWND is deleted too.
//
// This class is meant to be used in a STA and is not multithread-safe.
-class BaseDropTarget : public IDropTarget {
+class DropTarget : public IDropTarget {
public:
- // Create a new BaseDropTarget associating it with the given HWND.
- explicit BaseDropTarget(HWND hwnd);
- virtual ~BaseDropTarget();
+ // Create a new DropTarget associating it with the given HWND.
+ explicit DropTarget(HWND hwnd);
+ virtual ~DropTarget();
// When suspended is set to |true|, the drop target does not receive drops
// from drags initiated within the owning HWND.
@@ -123,7 +127,10 @@
LONG ref_count_;
- DISALLOW_COPY_AND_ASSIGN(BaseDropTarget);
+ DISALLOW_COPY_AND_ASSIGN(DropTarget);
};
-#endif // BASE_BASE_DROP_TARGET_H_
+} // namespace win
+} // namespace app
+
+#endif // APP_WIN_DROP_TARGET_H_
« no previous file with comments | « app/win/drag_source.cc ('k') | app/win/drop_target.cc » ('j') | no next file with comments »

Powered by Google App Engine
@@ -2,30 +2,34 @@
// want to override various OnXXX methods.
//
-// Because BaseDropTarget is ref counted you shouldn't delete it directly,
+// Because DropTarget is ref counted you shouldn't delete it directly,
// rather wrap it in a scoped_refptr. Be sure and invoke RevokeDragDrop(m_hWnd)
// before the HWND is deleted too.
This is Rietveld 408576698